'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = BabelMinify;

var _babelCore = require('babel-core');

var _babelPresetMin = require('babel-preset-min');

var _babelPresetMin2 = _interopRequireDefault(_babelPresetMin);

var _babelPluginConditionalCompile = require('babel-plugin-conditional-compile');

var _babelPluginConditionalCompile2 = _interopRequireDefault(_babelPluginConditionalCompile);

var _babelPluginTransformEvaluate = require('babel-plugin-transform-evaluate');

var _babelPluginTransformEvaluate2 = _interopRequireDefault(_babelPluginTransformEvaluate);

var _babelPluginTransformRemoveDebugger = require('babel-plugin-transform-remove-debugger');

var _babelPluginTransformRemoveDebugger2 = _interopRequireDefault(_babelPluginTransformRemoveDebugger);

var _babelPluginTransformRemoveConsole = require('babel-plugin-transform-remove-console');

var _babelPluginTransformRemoveConsole2 = _interopRequireDefault(_babelPluginTransformRemoveConsole);

var _babelPluginTransformDeadCodeElimination = require('babel-plugin-transform-dead-code-elimination');

var _babelPluginTransformDeadCodeElimination2 = _interopRequireDefault(_babelPluginTransformDeadCodeElimination);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const defaultPlugins = _babelPresetMin2.default.plugins;

// other plugins


const DEV = process.env.NODE_ENV !== 'production';
const PROD = !DEV;

function BabelMinify(inputCode) {
  var _ref = arguments.length <= 1 || arguments[1] === undefined ? {} : arguments[1];

  var _ref$conditionals = _ref.conditionals;
  let
  // optimize if-s
  conditionals = _ref$conditionals === undefined ? true : _ref$conditionals;
  var _ref$global_defs = _ref.global_defs;
  let global_defs = _ref$global_defs === undefined ? {
    DEV: DEV,
    PROD: PROD,
    __DEV__: DEV,
    __PROD__: PROD
  } : _ref$global_defs;
  var _ref$evaluate = _ref.evaluate;
  let

  // eval constant expressions
  evaluate = _ref$evaluate === undefined ? true : _ref$evaluate;
  var _ref$dead_code = _ref.dead_code;
  let

  // dead_code eliminication
  dead_code = _ref$dead_code === undefined ? false : _ref$dead_code;
  var _ref$drop_debugger = _ref.drop_debugger;
  let drop_debugger = _ref$drop_debugger === undefined ? false : _ref$drop_debugger;
  var _ref$drop_console = _ref.drop_console;
  let drop_console = _ref$drop_console === undefined ? false : _ref$drop_console;
  var _ref$babelrc = _ref.babelrc;
  let

  // passed on to babel transform to tell whether to use babelrc
  babelrc = _ref$babelrc === undefined ? false : _ref$babelrc;


  if (!inputCode) throw new Error('Invalid Input');

  const optionalPlugins = [];

  if (conditionals) {
    if (global_defs) {
      optionalPlugins.push([_babelPluginConditionalCompile2.default, {
        define: global_defs
      }]);
    } else {
      optionalPlugins.push(_babelPluginConditionalCompile2.default);
    }
  }

  evaluate && optionalPlugins.push(_babelPluginTransformEvaluate2.default);
  dead_code && optionalPlugins.push(_babelPluginTransformDeadCodeElimination2.default);
  drop_debugger && optionalPlugins.push(_babelPluginTransformRemoveDebugger2.default);
  drop_console && optionalPlugins.push(_babelPluginTransformRemoveConsole2.default);

  const result = (0, _babelCore.transform)(inputCode, {
    babelrc: babelrc,
    comments: false,
    compact: true,
    minified: true,
    plugins: [].concat(defaultPlugins, optionalPlugins)
  });

  return result.code;
}
module.exports = exports['default'];